# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class HistoricActivityInstanceQueryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'activity_instance_id': 'str',
        'process_instance_id': 'str',
        'process_definition_id': 'str',
        'execution_id': 'str',
        'activity_id': 'str',
        'activity_name': 'str',
        'activity_type': 'str',
        'task_assignee': 'str',
        'finished': 'bool',
        'unfinished': 'bool',
        'canceled': 'bool',
        'complete_scope': 'bool',
        'started_before': 'datetime',
        'started_after': 'datetime',
        'finished_before': 'datetime',
        'finished_after': 'datetime',
        'tenant_id_in': 'list[str]',
        'without_tenant_id': 'bool',
        'sorting': 'list[HistoricActivityInstanceQueryDtoSorting]'
    }

    attribute_map = {
        'activity_instance_id': 'activityInstanceId',
        'process_instance_id': 'processInstanceId',
        'process_definition_id': 'processDefinitionId',
        'execution_id': 'executionId',
        'activity_id': 'activityId',
        'activity_name': 'activityName',
        'activity_type': 'activityType',
        'task_assignee': 'taskAssignee',
        'finished': 'finished',
        'unfinished': 'unfinished',
        'canceled': 'canceled',
        'complete_scope': 'completeScope',
        'started_before': 'startedBefore',
        'started_after': 'startedAfter',
        'finished_before': 'finishedBefore',
        'finished_after': 'finishedAfter',
        'tenant_id_in': 'tenantIdIn',
        'without_tenant_id': 'withoutTenantId',
        'sorting': 'sorting'
    }

    def __init__(self, activity_instance_id=None, process_instance_id=None, process_definition_id=None, execution_id=None, activity_id=None, activity_name=None, activity_type=None, task_assignee=None, finished=None, unfinished=None, canceled=None, complete_scope=None, started_before=None, started_after=None, finished_before=None, finished_after=None, tenant_id_in=None, without_tenant_id=None, sorting=None, local_vars_configuration=None):  # noqa: E501
        """HistoricActivityInstanceQueryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._activity_instance_id = None
        self._process_instance_id = None
        self._process_definition_id = None
        self._execution_id = None
        self._activity_id = None
        self._activity_name = None
        self._activity_type = None
        self._task_assignee = None
        self._finished = None
        self._unfinished = None
        self._canceled = None
        self._complete_scope = None
        self._started_before = None
        self._started_after = None
        self._finished_before = None
        self._finished_after = None
        self._tenant_id_in = None
        self._without_tenant_id = None
        self._sorting = None
        self.discriminator = None

        if activity_instance_id is not None:
            self.activity_instance_id = activity_instance_id
        if process_instance_id is not None:
            self.process_instance_id = process_instance_id
        if process_definition_id is not None:
            self.process_definition_id = process_definition_id
        if execution_id is not None:
            self.execution_id = execution_id
        if activity_id is not None:
            self.activity_id = activity_id
        if activity_name is not None:
            self.activity_name = activity_name
        if activity_type is not None:
            self.activity_type = activity_type
        if task_assignee is not None:
            self.task_assignee = task_assignee
        self.finished = finished
        self.unfinished = unfinished
        self.canceled = canceled
        self.complete_scope = complete_scope
        self.started_before = started_before
        self.started_after = started_after
        self.finished_before = finished_before
        self.finished_after = finished_after
        if tenant_id_in is not None:
            self.tenant_id_in = tenant_id_in
        self.without_tenant_id = without_tenant_id
        if sorting is not None:
            self.sorting = sorting

    @property
    def activity_instance_id(self):
        """Gets the activity_instance_id of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Filter by activity instance id.  # noqa: E501

        :return: The activity_instance_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_instance_id

    @activity_instance_id.setter
    def activity_instance_id(self, activity_instance_id):
        """Sets the activity_instance_id of this HistoricActivityInstanceQueryDto.

        Filter by activity instance id.  # noqa: E501

        :param activity_instance_id: The activity_instance_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._activity_instance_id = activity_instance_id

    @property
    def process_instance_id(self):
        """Gets the process_instance_id of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Filter by process instance id.  # noqa: E501

        :return: The process_instance_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, process_instance_id):
        """Sets the process_instance_id of this HistoricActivityInstanceQueryDto.

        Filter by process instance id.  # noqa: E501

        :param process_instance_id: The process_instance_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_instance_id = process_instance_id

    @property
    def process_definition_id(self):
        """Gets the process_definition_id of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Filter by process definition id.  # noqa: E501

        :return: The process_definition_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """Sets the process_definition_id of this HistoricActivityInstanceQueryDto.

        Filter by process definition id.  # noqa: E501

        :param process_definition_id: The process_definition_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._process_definition_id = process_definition_id

    @property
    def execution_id(self):
        """Gets the execution_id of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Filter by the id of the execution that executed the activity instance.  # noqa: E501

        :return: The execution_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this HistoricActivityInstanceQueryDto.

        Filter by the id of the execution that executed the activity instance.  # noqa: E501

        :param execution_id: The execution_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._execution_id = execution_id

    @property
    def activity_id(self):
        """Gets the activity_id of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Filter by the activity id (according to BPMN 2.0 XML).  # noqa: E501

        :return: The activity_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this HistoricActivityInstanceQueryDto.

        Filter by the activity id (according to BPMN 2.0 XML).  # noqa: E501

        :param activity_id: The activity_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._activity_id = activity_id

    @property
    def activity_name(self):
        """Gets the activity_name of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Filter by the activity name (according to BPMN 2.0 XML).  # noqa: E501

        :return: The activity_name of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_name

    @activity_name.setter
    def activity_name(self, activity_name):
        """Sets the activity_name of this HistoricActivityInstanceQueryDto.

        Filter by the activity name (according to BPMN 2.0 XML).  # noqa: E501

        :param activity_name: The activity_name of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._activity_name = activity_name

    @property
    def activity_type(self):
        """Gets the activity_type of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Filter by activity type.  # noqa: E501

        :return: The activity_type of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_type

    @activity_type.setter
    def activity_type(self, activity_type):
        """Sets the activity_type of this HistoricActivityInstanceQueryDto.

        Filter by activity type.  # noqa: E501

        :param activity_type: The activity_type of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._activity_type = activity_type

    @property
    def task_assignee(self):
        """Gets the task_assignee of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Only include activity instances that are user tasks and assigned to a given user.  # noqa: E501

        :return: The task_assignee of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: str
        """
        return self._task_assignee

    @task_assignee.setter
    def task_assignee(self, task_assignee):
        """Sets the task_assignee of this HistoricActivityInstanceQueryDto.

        Only include activity instances that are user tasks and assigned to a given user.  # noqa: E501

        :param task_assignee: The task_assignee of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: str
        """

        self._task_assignee = task_assignee

    @property
    def finished(self):
        """Gets the finished of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Only include finished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.  # noqa: E501

        :return: The finished of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._finished

    @finished.setter
    def finished(self, finished):
        """Sets the finished of this HistoricActivityInstanceQueryDto.

        Only include finished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.  # noqa: E501

        :param finished: The finished of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._finished = finished

    @property
    def unfinished(self):
        """Gets the unfinished of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Only include unfinished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.  # noqa: E501

        :return: The unfinished of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._unfinished

    @unfinished.setter
    def unfinished(self, unfinished):
        """Sets the unfinished of this HistoricActivityInstanceQueryDto.

        Only include unfinished activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.  # noqa: E501

        :param unfinished: The unfinished of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._unfinished = unfinished

    @property
    def canceled(self):
        """Gets the canceled of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Only include canceled activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.  # noqa: E501

        :return: The canceled of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._canceled

    @canceled.setter
    def canceled(self, canceled):
        """Sets the canceled of this HistoricActivityInstanceQueryDto.

        Only include canceled activity instances. Value may only be `true`, as `false` behaves the same as when the property is not set.  # noqa: E501

        :param canceled: The canceled of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._canceled = canceled

    @property
    def complete_scope(self):
        """Gets the complete_scope of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Only include activity instances which completed a scope. Value may only be `true`, as `false` behaves the same as when the property is not set.  # noqa: E501

        :return: The complete_scope of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._complete_scope

    @complete_scope.setter
    def complete_scope(self, complete_scope):
        """Sets the complete_scope of this HistoricActivityInstanceQueryDto.

        Only include activity instances which completed a scope. Value may only be `true`, as `false` behaves the same as when the property is not set.  # noqa: E501

        :param complete_scope: The complete_scope of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._complete_scope = complete_scope

    @property
    def started_before(self):
        """Gets the started_before of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Restrict to instances that were started before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The started_before of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._started_before

    @started_before.setter
    def started_before(self, started_before):
        """Sets the started_before of this HistoricActivityInstanceQueryDto.

        Restrict to instances that were started before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param started_before: The started_before of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._started_before = started_before

    @property
    def started_after(self):
        """Gets the started_after of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Restrict to instances that were started after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The started_after of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._started_after

    @started_after.setter
    def started_after(self, started_after):
        """Sets the started_after of this HistoricActivityInstanceQueryDto.

        Restrict to instances that were started after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param started_after: The started_after of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._started_after = started_after

    @property
    def finished_before(self):
        """Gets the finished_before of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Restrict to instances that were finished before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The finished_before of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_before

    @finished_before.setter
    def finished_before(self, finished_before):
        """Sets the finished_before of this HistoricActivityInstanceQueryDto.

        Restrict to instances that were finished before the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param finished_before: The finished_before of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._finished_before = finished_before

    @property
    def finished_after(self):
        """Gets the finished_after of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Restrict to instances that were finished after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :return: The finished_after of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_after

    @finished_after.setter
    def finished_after(self, finished_after):
        """Sets the finished_after of this HistoricActivityInstanceQueryDto.

        Restrict to instances that were finished after the given date. By [default](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/), the date must have the format `yyyy-MM-dd'T'HH:mm:ss.SSSZ`, e.g., `2013-01-23T14:42:45.000+0200`.  # noqa: E501

        :param finished_after: The finished_after of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: datetime
        """

        self._finished_after = finished_after

    @property
    def tenant_id_in(self):
        """Gets the tenant_id_in of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Must be a JSON array of Strings. An activity instance must have one of the given tenant ids.  # noqa: E501

        :return: The tenant_id_in of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._tenant_id_in

    @tenant_id_in.setter
    def tenant_id_in(self, tenant_id_in):
        """Sets the tenant_id_in of this HistoricActivityInstanceQueryDto.

        Must be a JSON array of Strings. An activity instance must have one of the given tenant ids.  # noqa: E501

        :param tenant_id_in: The tenant_id_in of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: list[str]
        """

        self._tenant_id_in = tenant_id_in

    @property
    def without_tenant_id(self):
        """Gets the without_tenant_id of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Only include historic activity instances that belong to no tenant. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The without_tenant_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: bool
        """
        return self._without_tenant_id

    @without_tenant_id.setter
    def without_tenant_id(self, without_tenant_id):
        """Sets the without_tenant_id of this HistoricActivityInstanceQueryDto.

        Only include historic activity instances that belong to no tenant. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param without_tenant_id: The without_tenant_id of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: bool
        """

        self._without_tenant_id = without_tenant_id

    @property
    def sorting(self):
        """Gets the sorting of this HistoricActivityInstanceQueryDto.  # noqa: E501

        Apply sorting of the result  # noqa: E501

        :return: The sorting of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :rtype: list[HistoricActivityInstanceQueryDtoSorting]
        """
        return self._sorting

    @sorting.setter
    def sorting(self, sorting):
        """Sets the sorting of this HistoricActivityInstanceQueryDto.

        Apply sorting of the result  # noqa: E501

        :param sorting: The sorting of this HistoricActivityInstanceQueryDto.  # noqa: E501
        :type: list[HistoricActivityInstanceQueryDtoSorting]
        """

        self._sorting = sorting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoricActivityInstanceQueryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HistoricActivityInstanceQueryDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.task_variable_api import TaskVariableApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestTaskVariableApi(unittest.TestCase):
    """TaskVariableApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.task_variable_api.TaskVariableApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_task_variable(self):
        """Test case for delete_task_variable

        """
        pass

    def test_get_task_variable(self):
        """Test case for get_task_variable

        """
        pass

    def test_get_task_variable_binary(self):
        """Test case for get_task_variable_binary

        """
        pass

    def test_get_task_variables(self):
        """Test case for get_task_variables

        """
        pass

    def test_modify_task_variables(self):
        """Test case for modify_task_variables

        """
        pass

    def test_put_task_variable(self):
        """Test case for put_task_variable

        """
        pass

    def test_set_binary_task_variable(self):
        """Test case for set_binary_task_variable

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.historic_activity_instance_query_dto import HistoricActivityInstanceQueryDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestHistoricActivityInstanceQueryDto(unittest.TestCase):
    """HistoricActivityInstanceQueryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test HistoricActivityInstanceQueryDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.historic_activity_instance_query_dto.HistoricActivityInstanceQueryDto()  # noqa: E501
        if include_optional :
            return HistoricActivityInstanceQueryDto(
                activity_instance_id = '0', 
                process_instance_id = '0', 
                process_definition_id = '0', 
                execution_id = '0', 
                activity_id = '0', 
                activity_name = '0', 
                activity_type = '0', 
                task_assignee = '0', 
                finished = True, 
                unfinished = True, 
                canceled = True, 
                complete_scope = True, 
                started_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                started_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                finished_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                finished_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                tenant_id_in = [
                    '0'
                    ], 
                without_tenant_id = True, 
                sorting = [
                    generic_camunda_client.models.historic_activity_instance_query_dto_sorting.HistoricActivityInstanceQueryDto_sorting(
                        sort_by = 'activityInstanceId', 
                        sort_order = 'asc', )
                    ]
            )
        else :
            return HistoricActivityInstanceQueryDto(
        )

    def testHistoricActivityInstanceQueryDto(self):
        """Test HistoricActivityInstanceQueryDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.external_task_api import ExternalTaskApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestExternalTaskApi(unittest.TestCase):
    """ExternalTaskApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.external_task_api.ExternalTaskApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_external_task_resource(self):
        """Test case for complete_external_task_resource

        """
        pass

    def test_extend_lock(self):
        """Test case for extend_lock

        """
        pass

    def test_fetch_and_lock(self):
        """Test case for fetch_and_lock

        """
        pass

    def test_get_external_task(self):
        """Test case for get_external_task

        """
        pass

    def test_get_external_task_error_details(self):
        """Test case for get_external_task_error_details

        """
        pass

    def test_get_external_tasks(self):
        """Test case for get_external_tasks

        """
        pass

    def test_get_external_tasks_count(self):
        """Test case for get_external_tasks_count

        """
        pass

    def test_get_topic_names(self):
        """Test case for get_topic_names

        """
        pass

    def test_handle_external_task_bpmn_error(self):
        """Test case for handle_external_task_bpmn_error

        """
        pass

    def test_handle_failure(self):
        """Test case for handle_failure

        """
        pass

    def test_query_external_tasks(self):
        """Test case for query_external_tasks

        """
        pass

    def test_query_external_tasks_count(self):
        """Test case for query_external_tasks_count

        """
        pass

    def test_set_external_task_resource_priority(self):
        """Test case for set_external_task_resource_priority

        """
        pass

    def test_set_external_task_resource_retries(self):
        """Test case for set_external_task_resource_retries

        """
        pass

    def test_set_external_task_retries(self):
        """Test case for set_external_task_retries

        """
        pass

    def test_set_external_task_retries_async_operation(self):
        """Test case for set_external_task_retries_async_operation

        """
        pass

    def test_unlock(self):
        """Test case for unlock

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.parse_exception_dto import ParseExceptionDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestParseExceptionDto(unittest.TestCase):
    """ParseExceptionDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ParseExceptionDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.parse_exception_dto.ParseExceptionDto()  # noqa: E501
        if include_optional :
            return ParseExceptionDto(
                details = {
                    'key' : generic_camunda_client.models.resource_report_dto.ResourceReportDto(
                        errors = [
                            generic_camunda_client.models.problem_dto.ProblemDto(
                                message = '0', 
                                line = 56, 
                                column = 56, 
                                main_element_id = '0', 
                                element_ids = [
                                    '0'
                                    ], )
                            ], 
                        warnings = [
                            generic_camunda_client.models.problem_dto.ProblemDto(
                                message = '0', 
                                line = 56, 
                                column = 56, 
                                main_element_id = '0', )
                            ], )
                    }, 
                type = '0', 
                message = '0'
            )
        else :
            return ParseExceptionDto(
        )

    def testParseExceptionDto(self):
        """Test ParseExceptionDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class EvaluationConditionDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'variables': 'dict(str, VariableValueDto)',
        'business_key': 'str',
        'tenant_id': 'str',
        'without_tenant_id': 'bool',
        'process_definition_id': 'str'
    }

    attribute_map = {
        'variables': 'variables',
        'business_key': 'businessKey',
        'tenant_id': 'tenantId',
        'without_tenant_id': 'withoutTenantId',
        'process_definition_id': 'processDefinitionId'
    }

    def __init__(self, variables=None, business_key=None, tenant_id=None, without_tenant_id=None, process_definition_id=None, local_vars_configuration=None):  # noqa: E501
        """EvaluationConditionDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._variables = None
        self._business_key = None
        self._tenant_id = None
        self._without_tenant_id = None
        self._process_definition_id = None
        self.discriminator = None

        if variables is not None:
            self.variables = variables
        if business_key is not None:
            self.business_key = business_key
        if tenant_id is not None:
            self.tenant_id = tenant_id
        self.without_tenant_id = without_tenant_id
        if process_definition_id is not None:
            self.process_definition_id = process_definition_id

    @property
    def variables(self):
        """Gets the variables of this EvaluationConditionDto.  # noqa: E501

        A map of variables which are used for evaluation of the conditions and are injected into the process instances which have been triggered. Each key is a variable name and each value a JSON variable value object with the following properties.  # noqa: E501

        :return: The variables of this EvaluationConditionDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this EvaluationConditionDto.

        A map of variables which are used for evaluation of the conditions and are injected into the process instances which have been triggered. Each key is a variable name and each value a JSON variable value object with the following properties.  # noqa: E501

        :param variables: The variables of this EvaluationConditionDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._variables = variables

    @property
    def business_key(self):
        """Gets the business_key of this EvaluationConditionDto.  # noqa: E501

        Used for the process instances that have been triggered after the evaluation.  # noqa: E501

        :return: The business_key of this EvaluationConditionDto.  # noqa: E501
        :rtype: str
        """
        return self._business_key

    @business_key.setter
    def business_key(self, business_key):
        """Sets the business_key of this EvaluationConditionDto.

        Used for the process instances that have been triggered after the evaluation.  # noqa: E501

        :param business_key: The business_key of this EvaluationConditionDto.  # noqa: E501
        :type: str
        """

        self._business_key = business_key

    @property
    def tenant_id(self):
        """Gets the tenant_id of this EvaluationConditionDto.  # noqa: E501

        Used to evaluate a condition for a tenant with the given id. Will only evaluate conditions of process definitions which belong to the tenant.  # noqa: E501

        :return: The tenant_id of this EvaluationConditionDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this EvaluationConditionDto.

        Used to evaluate a condition for a tenant with the given id. Will only evaluate conditions of process definitions which belong to the tenant.  # noqa: E501

        :param tenant_id: The tenant_id of this EvaluationConditionDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def without_tenant_id(self):
        """Gets the without_tenant_id of this EvaluationConditionDto.  # noqa: E501

        A Boolean value that indicates whether the conditions should only be evaluated of process definitions which belong to no tenant or not. Value may only be true, as false is the default behavior.  # noqa: E501

        :return: The without_tenant_id of this EvaluationConditionDto.  # noqa: E501
        :rtype: bool
        """
        return self._without_tenant_id

    @without_tenant_id.setter
    def without_tenant_id(self, without_tenant_id):
        """Sets the without_tenant_id of this EvaluationConditionDto.

        A Boolean value that indicates whether the conditions should only be evaluated of process definitions which belong to no tenant or not. Value may only be true, as false is the default behavior.  # noqa: E501

        :param without_tenant_id: The without_tenant_id of this EvaluationConditionDto.  # noqa: E501
        :type: bool
        """

        self._without_tenant_id = without_tenant_id

    @property
    def process_definition_id(self):
        """Gets the process_definition_id of this EvaluationConditionDto.  # noqa: E501

        Used to evaluate conditions of the process definition with the given id.  # noqa: E501

        :return: The process_definition_id of this EvaluationConditionDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """Sets the process_definition_id of this EvaluationConditionDto.

        Used to evaluate conditions of the process definition with the given id.  # noqa: E501

        :param process_definition_id: The process_definition_id of this EvaluationConditionDto.  # noqa: E501
        :type: str
        """

        self._process_definition_id = process_definition_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EvaluationConditionDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EvaluationConditionDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.historic_process_instance_query_dto import HistoricProcessInstanceQueryDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestHistoricProcessInstanceQueryDto(unittest.TestCase):
    """HistoricProcessInstanceQueryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test HistoricProcessInstanceQueryDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.historic_process_instance_query_dto.HistoricProcessInstanceQueryDto()  # noqa: E501
        if include_optional :
            return HistoricProcessInstanceQueryDto(
                process_instance_id = '0', 
                process_instance_ids = [
                    '0'
                    ], 
                process_definition_id = '0', 
                process_definition_key = '0', 
                process_definition_key_in = [
                    '0'
                    ], 
                process_definition_name = '0', 
                process_definition_name_like = '0', 
                process_definition_key_not_in = [
                    '0'
                    ], 
                process_instance_business_key = '0', 
                process_instance_business_key_like = '0', 
                root_process_instances = True, 
                finished = True, 
                unfinished = True, 
                with_incidents = True, 
                with_root_incidents = True, 
                incident_type = '0', 
                incident_status = 'open', 
                incident_message = '0', 
                incident_message_like = '0', 
                started_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                started_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                finished_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                finished_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                executed_activity_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                executed_activity_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                executed_job_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                executed_job_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                started_by = '0', 
                super_process_instance_id = '0', 
                sub_process_instance_id = '0', 
                super_case_instance_id = '0', 
                sub_case_instance_id = '0', 
                case_instance_id = '0', 
                tenant_id_in = [
                    '0'
                    ], 
                without_tenant_id = True, 
                executed_activity_id_in = [
                    '0'
                    ], 
                active_activity_id_in = [
                    '0'
                    ], 
                active = True, 
                suspended = True, 
                completed = True, 
                externally_terminated = True, 
                internally_terminated = True, 
                variables = [
                    generic_camunda_client.models.variable_query_parameter_dto.VariableQueryParameterDto(
                        name = '0', 
                        operator = 'eq', 
                        value = generic_camunda_client.models.value.value(), )
                    ], 
                variable_names_ignore_case = True, 
                variable_values_ignore_case = True, 
                or_queries = [
                    generic_camunda_client.models.historic_process_instance_query_dto.HistoricProcessInstanceQueryDto(
                        process_instance_id = '0', 
                        process_instance_ids = [
                            '0'
                            ], 
                        process_definition_id = '0', 
                        process_definition_key = '0', 
                        process_definition_key_in = [
                            '0'
                            ], 
                        process_definition_name = '0', 
                        process_definition_name_like = '0', 
                        process_definition_key_not_in = [
                            '0'
                            ], 
                        process_instance_business_key = '0', 
                        process_instance_business_key_like = '0', 
                        root_process_instances = True, 
                        finished = True, 
                        unfinished = True, 
                        with_incidents = True, 
                        with_root_incidents = True, 
                        incident_type = '0', 
                        incident_status = 'open', 
                        incident_message = '0', 
                        incident_message_like = '0', 
                        started_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        executed_activity_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        executed_activity_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        executed_job_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        executed_job_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_by = '0', 
                        super_process_instance_id = '0', 
                        sub_process_instance_id = '0', 
                        super_case_instance_id = '0', 
                        sub_case_instance_id = '0', 
                        case_instance_id = '0', 
                        tenant_id_in = [
                            '0'
                            ], 
                        without_tenant_id = True, 
                        executed_activity_id_in = [
                            '0'
                            ], 
                        active_activity_id_in = [
                            '0'
                            ], 
                        active = True, 
                        suspended = True, 
                        completed = True, 
                        externally_terminated = True, 
                        internally_terminated = True, 
                        variables = [
                            generic_camunda_client.models.variable_query_parameter_dto.VariableQueryParameterDto(
                                name = '0', 
                                operator = 'eq', 
                                value = generic_camunda_client.models.value.value(), )
                            ], 
                        variable_names_ignore_case = True, 
                        variable_values_ignore_case = True, 
                        sorting = [
                            generic_camunda_client.models.historic_process_instance_query_dto_sorting.HistoricProcessInstanceQueryDto_sorting(
                                sort_by = 'instanceId', 
                                sort_order = 'asc', )
                            ], )
                    ], 
                sorting = [
                    generic_camunda_client.models.historic_process_instance_query_dto_sorting.HistoricProcessInstanceQueryDto_sorting(
                        sort_by = 'instanceId', 
                        sort_order = 'asc', )
                    ]
            )
        else :
            return HistoricProcessInstanceQueryDto(
        )

    def testHistoricProcessInstanceQueryDto(self):
        """Test HistoricProcessInstanceQueryDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.fetch_external_tasks_dto import FetchExternalTasksDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestFetchExternalTasksDto(unittest.TestCase):
    """FetchExternalTasksDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FetchExternalTasksDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.fetch_external_tasks_dto.FetchExternalTasksDto()  # noqa: E501
        if include_optional :
            return FetchExternalTasksDto(
                worker_id = '0', 
                max_tasks = 56, 
                use_priority = True, 
                async_response_timeout = 56, 
                topics = [
                    generic_camunda_client.models.fetch_external_task_topic_dto.FetchExternalTaskTopicDto(
                        topic_name = '0', 
                        lock_duration = 56, 
                        variables = [
                            '0'
                            ], 
                        local_variables = True, 
                        business_key = '0', 
                        process_definition_id = '0', 
                        process_definition_id_in = [
                            '0'
                            ], 
                        process_definition_key = '0', 
                        process_definition_key_in = [
                            '0'
                            ], 
                        process_definition_version_tag = '0', 
                        without_tenant_id = True, 
                        tenant_id_in = [
                            '0'
                            ], 
                        process_variables = { }, 
                        deserialize_values = True, 
                        include_extension_properties = True, )
                    ]
            )
        else :
            return FetchExternalTasksDto(
                worker_id = '0',
                max_tasks = 56,
        )

    def testFetchExternalTasksDto(self):
        """Test FetchExternalTasksDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class CompleteExternalTaskDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'worker_id': 'str',
        'variables': 'dict(str, VariableValueDto)',
        'local_variables': 'dict(str, VariableValueDto)'
    }

    attribute_map = {
        'worker_id': 'workerId',
        'variables': 'variables',
        'local_variables': 'localVariables'
    }

    def __init__(self, worker_id=None, variables=None, local_variables=None, local_vars_configuration=None):  # noqa: E501
        """CompleteExternalTaskDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._worker_id = None
        self._variables = None
        self._local_variables = None
        self.discriminator = None

        if worker_id is not None:
            self.worker_id = worker_id
        if variables is not None:
            self.variables = variables
        if local_variables is not None:
            self.local_variables = local_variables

    @property
    def worker_id(self):
        """Gets the worker_id of this CompleteExternalTaskDto.  # noqa: E501

        The id of the worker that completes the task. Must match the id of the worker who has most recently locked the task.  # noqa: E501

        :return: The worker_id of this CompleteExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._worker_id

    @worker_id.setter
    def worker_id(self, worker_id):
        """Sets the worker_id of this CompleteExternalTaskDto.

        The id of the worker that completes the task. Must match the id of the worker who has most recently locked the task.  # noqa: E501

        :param worker_id: The worker_id of this CompleteExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._worker_id = worker_id

    @property
    def variables(self):
        """Gets the variables of this CompleteExternalTaskDto.  # noqa: E501

        A JSON object containing variable key-value pairs. Each key is a variable name and each value a JSON variable value object with the following properties:  # noqa: E501

        :return: The variables of this CompleteExternalTaskDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this CompleteExternalTaskDto.

        A JSON object containing variable key-value pairs. Each key is a variable name and each value a JSON variable value object with the following properties:  # noqa: E501

        :param variables: The variables of this CompleteExternalTaskDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._variables = variables

    @property
    def local_variables(self):
        """Gets the local_variables of this CompleteExternalTaskDto.  # noqa: E501

        A JSON object containing local variable key-value pairs. Local variables are set only in the scope of external task. Each key is a variable name and each value a JSON variable value object with the following properties:  # noqa: E501

        :return: The local_variables of this CompleteExternalTaskDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._local_variables

    @local_variables.setter
    def local_variables(self, local_variables):
        """Sets the local_variables of this CompleteExternalTaskDto.

        A JSON object containing local variable key-value pairs. Local variables are set only in the scope of external task. Each key is a variable name and each value a JSON variable value object with the following properties:  # noqa: E501

        :param local_variables: The local_variables of this CompleteExternalTaskDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._local_variables = local_variables

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompleteExternalTaskDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompleteExternalTaskDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class MultiFormDeploymentDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tenant_id': 'str',
        'deployment_source': 'str',
        'deploy_changed_only': 'bool',
        'enable_duplicate_filtering': 'bool',
        'deployment_name': 'str',
        'data': 'file'
    }

    attribute_map = {
        'tenant_id': 'tenant-id',
        'deployment_source': 'deployment-source',
        'deploy_changed_only': 'deploy-changed-only',
        'enable_duplicate_filtering': 'enable-duplicate-filtering',
        'deployment_name': 'deployment-name',
        'data': 'data'
    }

    def __init__(self, tenant_id=None, deployment_source=None, deploy_changed_only=False, enable_duplicate_filtering=False, deployment_name=None, data=None, local_vars_configuration=None):  # noqa: E501
        """MultiFormDeploymentDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._tenant_id = None
        self._deployment_source = None
        self._deploy_changed_only = None
        self._enable_duplicate_filtering = None
        self._deployment_name = None
        self._data = None
        self.discriminator = None

        if tenant_id is not None:
            self.tenant_id = tenant_id
        if deployment_source is not None:
            self.deployment_source = deployment_source
        self.deploy_changed_only = deploy_changed_only
        self.enable_duplicate_filtering = enable_duplicate_filtering
        if deployment_name is not None:
            self.deployment_name = deployment_name
        self.data = data

    @property
    def tenant_id(self):
        """Gets the tenant_id of this MultiFormDeploymentDto.  # noqa: E501

        The tenant id for the deployment to be created.  # noqa: E501

        :return: The tenant_id of this MultiFormDeploymentDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this MultiFormDeploymentDto.

        The tenant id for the deployment to be created.  # noqa: E501

        :param tenant_id: The tenant_id of this MultiFormDeploymentDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def deployment_source(self):
        """Gets the deployment_source of this MultiFormDeploymentDto.  # noqa: E501

        The source for the deployment to be created.  # noqa: E501

        :return: The deployment_source of this MultiFormDeploymentDto.  # noqa: E501
        :rtype: str
        """
        return self._deployment_source

    @deployment_source.setter
    def deployment_source(self, deployment_source):
        """Sets the deployment_source of this MultiFormDeploymentDto.

        The source for the deployment to be created.  # noqa: E501

        :param deployment_source: The deployment_source of this MultiFormDeploymentDto.  # noqa: E501
        :type: str
        """

        self._deployment_source = deployment_source

    @property
    def deploy_changed_only(self):
        """Gets the deploy_changed_only of this MultiFormDeploymentDto.  # noqa: E501

        A flag indicating whether the process engine should perform duplicate checking on a per-resource basis. If set to true, only those resources that have actually changed are deployed. Checks are made against resources included previous deployments of the same name and only against the latest versions of those resources. If set to true, the option enable-duplicate-filtering is overridden and set to true.  # noqa: E501

        :return: The deploy_changed_only of this MultiFormDeploymentDto.  # noqa: E501
        :rtype: bool
        """
        return self._deploy_changed_only

    @deploy_changed_only.setter
    def deploy_changed_only(self, deploy_changed_only):
        """Sets the deploy_changed_only of this MultiFormDeploymentDto.

        A flag indicating whether the process engine should perform duplicate checking on a per-resource basis. If set to true, only those resources that have actually changed are deployed. Checks are made against resources included previous deployments of the same name and only against the latest versions of those resources. If set to true, the option enable-duplicate-filtering is overridden and set to true.  # noqa: E501

        :param deploy_changed_only: The deploy_changed_only of this MultiFormDeploymentDto.  # noqa: E501
        :type: bool
        """

        self._deploy_changed_only = deploy_changed_only

    @property
    def enable_duplicate_filtering(self):
        """Gets the enable_duplicate_filtering of this MultiFormDeploymentDto.  # noqa: E501

        A flag indicating whether the process engine should perform duplicate checking for the deployment or not. This allows you to check if a deployment with the same name and the same resouces already exists and if true, not create a new deployment but instead return the existing deployment. The default value is false.  # noqa: E501

        :return: The enable_duplicate_filtering of this MultiFormDeploymentDto.  # noqa: E501
        :rtype: bool
        """
        return self._enable_duplicate_filtering

    @enable_duplicate_filtering.setter
    def enable_duplicate_filtering(self, enable_duplicate_filtering):
        """Sets the enable_duplicate_filtering of this MultiFormDeploymentDto.

        A flag indicating whether the process engine should perform duplicate checking for the deployment or not. This allows you to check if a deployment with the same name and the same resouces already exists and if true, not create a new deployment but instead return the existing deployment. The default value is false.  # noqa: E501

        :param enable_duplicate_filtering: The enable_duplicate_filtering of this MultiFormDeploymentDto.  # noqa: E501
        :type: bool
        """

        self._enable_duplicate_filtering = enable_duplicate_filtering

    @property
    def deployment_name(self):
        """Gets the deployment_name of this MultiFormDeploymentDto.  # noqa: E501

        The name for the deployment to be created.  # noqa: E501

        :return: The deployment_name of this MultiFormDeploymentDto.  # noqa: E501
        :rtype: str
        """
        return self._deployment_name

    @deployment_name.setter
    def deployment_name(self, deployment_name):
        """Sets the deployment_name of this MultiFormDeploymentDto.

        The name for the deployment to be created.  # noqa: E501

        :param deployment_name: The deployment_name of this MultiFormDeploymentDto.  # noqa: E501
        :type: str
        """

        self._deployment_name = deployment_name

    @property
    def data(self):
        """Gets the data of this MultiFormDeploymentDto.  # noqa: E501

        The binary data to create the deployment resource. It is possible to have more than one form part with different form part names for the binary data to create a deployment.  # noqa: E501

        :return: The data of this MultiFormDeploymentDto.  # noqa: E501
        :rtype: file
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this MultiFormDeploymentDto.

        The binary data to create the deployment resource. It is possible to have more than one form part with different form part names for the binary data to create a deployment.  # noqa: E501

        :param data: The data of this MultiFormDeploymentDto.  # noqa: E501
        :type: file
        """

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MultiFormDeploymentDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MultiFormDeploymentDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class DeploymentWithDefinitionsDtoAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'deployed_process_definitions': 'dict(str, ProcessDefinitionDto)',
        'deployed_decision_definitions': 'dict(str, DecisionDefinitionDto)',
        'deployed_decision_requirements_definitions': 'dict(str, DecisionRequirementsDefinitionDto)',
        'deployed_case_definitions': 'dict(str, CaseDefinitionDto)'
    }

    attribute_map = {
        'deployed_process_definitions': 'deployedProcessDefinitions',
        'deployed_decision_definitions': 'deployedDecisionDefinitions',
        'deployed_decision_requirements_definitions': 'deployedDecisionRequirementsDefinitions',
        'deployed_case_definitions': 'deployedCaseDefinitions'
    }

    def __init__(self, deployed_process_definitions=None, deployed_decision_definitions=None, deployed_decision_requirements_definitions=None, deployed_case_definitions=None, local_vars_configuration=None):  # noqa: E501
        """DeploymentWithDefinitionsDtoAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._deployed_process_definitions = None
        self._deployed_decision_definitions = None
        self._deployed_decision_requirements_definitions = None
        self._deployed_case_definitions = None
        self.discriminator = None

        if deployed_process_definitions is not None:
            self.deployed_process_definitions = deployed_process_definitions
        if deployed_decision_definitions is not None:
            self.deployed_decision_definitions = deployed_decision_definitions
        if deployed_decision_requirements_definitions is not None:
            self.deployed_decision_requirements_definitions = deployed_decision_requirements_definitions
        if deployed_case_definitions is not None:
            self.deployed_case_definitions = deployed_case_definitions

    @property
    def deployed_process_definitions(self):
        """Gets the deployed_process_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501

        A JSON Object containing a property for each of the process definitions, which are successfully deployed with that deployment. The key is the process definition id, the value is a JSON Object corresponding to the process definition.  # noqa: E501

        :return: The deployed_process_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501
        :rtype: dict(str, ProcessDefinitionDto)
        """
        return self._deployed_process_definitions

    @deployed_process_definitions.setter
    def deployed_process_definitions(self, deployed_process_definitions):
        """Sets the deployed_process_definitions of this DeploymentWithDefinitionsDtoAllOf.

        A JSON Object containing a property for each of the process definitions, which are successfully deployed with that deployment. The key is the process definition id, the value is a JSON Object corresponding to the process definition.  # noqa: E501

        :param deployed_process_definitions: The deployed_process_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501
        :type: dict(str, ProcessDefinitionDto)
        """

        self._deployed_process_definitions = deployed_process_definitions

    @property
    def deployed_decision_definitions(self):
        """Gets the deployed_decision_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501

        A JSON Object containing a property for each of the decision definitions, which are successfully deployed with that deployment. The key is the decision definition id, the value is a JSON Object corresponding to the decision definition.  # noqa: E501

        :return: The deployed_decision_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501
        :rtype: dict(str, DecisionDefinitionDto)
        """
        return self._deployed_decision_definitions

    @deployed_decision_definitions.setter
    def deployed_decision_definitions(self, deployed_decision_definitions):
        """Sets the deployed_decision_definitions of this DeploymentWithDefinitionsDtoAllOf.

        A JSON Object containing a property for each of the decision definitions, which are successfully deployed with that deployment. The key is the decision definition id, the value is a JSON Object corresponding to the decision definition.  # noqa: E501

        :param deployed_decision_definitions: The deployed_decision_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501
        :type: dict(str, DecisionDefinitionDto)
        """

        self._deployed_decision_definitions = deployed_decision_definitions

    @property
    def deployed_decision_requirements_definitions(self):
        """Gets the deployed_decision_requirements_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501

        A JSON Object containing a property for each of the decision requirements definitions, which are successfully deployed with that deployment. The key is the decision requirements definition id, the value is a JSON Object corresponding to the decision requirements definition.  # noqa: E501

        :return: The deployed_decision_requirements_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501
        :rtype: dict(str, DecisionRequirementsDefinitionDto)
        """
        return self._deployed_decision_requirements_definitions

    @deployed_decision_requirements_definitions.setter
    def deployed_decision_requirements_definitions(self, deployed_decision_requirements_definitions):
        """Sets the deployed_decision_requirements_definitions of this DeploymentWithDefinitionsDtoAllOf.

        A JSON Object containing a property for each of the decision requirements definitions, which are successfully deployed with that deployment. The key is the decision requirements definition id, the value is a JSON Object corresponding to the decision requirements definition.  # noqa: E501

        :param deployed_decision_requirements_definitions: The deployed_decision_requirements_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501
        :type: dict(str, DecisionRequirementsDefinitionDto)
        """

        self._deployed_decision_requirements_definitions = deployed_decision_requirements_definitions

    @property
    def deployed_case_definitions(self):
        """Gets the deployed_case_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501

        A JSON Object containing a property for each of the case definitions, which are successfully deployed with that deployment. The key is the case definition id, the value is a JSON Object corresponding to the case definition.  # noqa: E501

        :return: The deployed_case_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501
        :rtype: dict(str, CaseDefinitionDto)
        """
        return self._deployed_case_definitions

    @deployed_case_definitions.setter
    def deployed_case_definitions(self, deployed_case_definitions):
        """Sets the deployed_case_definitions of this DeploymentWithDefinitionsDtoAllOf.

        A JSON Object containing a property for each of the case definitions, which are successfully deployed with that deployment. The key is the case definition id, the value is a JSON Object corresponding to the case definition.  # noqa: E501

        :param deployed_case_definitions: The deployed_case_definitions of this DeploymentWithDefinitionsDtoAllOf.  # noqa: E501
        :type: dict(str, CaseDefinitionDto)
        """

        self._deployed_case_definitions = deployed_case_definitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeploymentWithDefinitionsDtoAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeploymentWithDefinitionsDtoAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.set_job_retries_by_process_dto import SetJobRetriesByProcessDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestSetJobRetriesByProcessDto(unittest.TestCase):
    """SetJobRetriesByProcessDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SetJobRetriesByProcessDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.set_job_retries_by_process_dto.SetJobRetriesByProcessDto()  # noqa: E501
        if include_optional :
            return SetJobRetriesByProcessDto(
                process_instances = [
                    '0'
                    ], 
                retries = 0, 
                process_instance_query = generic_camunda_client.models.process_instance_query_dto.ProcessInstanceQueryDto(
                    deployment_id = '0', 
                    process_definition_id = '0', 
                    process_definition_key = '0', 
                    process_definition_key_in = [
                        '0'
                        ], 
                    process_definition_key_not_in = [
                        '0'
                        ], 
                    business_key = '0', 
                    business_key_like = '0', 
                    case_instance_id = '0', 
                    super_process_instance = '0', 
                    sub_process_instance = '0', 
                    super_case_instance = '0', 
                    sub_case_instance = '0', 
                    active = True, 
                    suspended = True, 
                    process_instance_ids = [
                        '0'
                        ], 
                    with_incident = True, 
                    incident_id = '0', 
                    incident_type = '0', 
                    incident_message = '0', 
                    incident_message_like = '0', 
                    tenant_id_in = [
                        '0'
                        ], 
                    without_tenant_id = True, 
                    process_definition_without_tenant_id = True, 
                    activity_id_in = [
                        '0'
                        ], 
                    root_process_instances = True, 
                    leaf_process_instances = True, 
                    variables = [
                        generic_camunda_client.models.variable_query_parameter_dto.VariableQueryParameterDto(
                            name = '0', 
                            operator = 'eq', 
                            value = generic_camunda_client.models.value.value(), )
                        ], 
                    variable_names_ignore_case = True, 
                    variable_values_ignore_case = True, 
                    or_queries = [
                        generic_camunda_client.models.process_instance_query_dto.ProcessInstanceQueryDto(
                            deployment_id = '0', 
                            process_definition_id = '0', 
                            process_definition_key = '0', 
                            business_key = '0', 
                            business_key_like = '0', 
                            case_instance_id = '0', 
                            super_process_instance = '0', 
                            sub_process_instance = '0', 
                            super_case_instance = '0', 
                            sub_case_instance = '0', 
                            active = True, 
                            suspended = True, 
                            with_incident = True, 
                            incident_id = '0', 
                            incident_type = '0', 
                            incident_message = '0', 
                            incident_message_like = '0', 
                            without_tenant_id = True, 
                            process_definition_without_tenant_id = True, 
                            root_process_instances = True, 
                            leaf_process_instances = True, 
                            variable_names_ignore_case = True, 
                            variable_values_ignore_case = True, 
                            sorting = [
                                generic_camunda_client.models.process_instance_query_dto_sorting.ProcessInstanceQueryDto_sorting(
                                    sort_by = 'instanceId', 
                                    sort_order = 'asc', )
                                ], )
                        ], 
                    sorting = [
                        generic_camunda_client.models.process_instance_query_dto_sorting.ProcessInstanceQueryDto_sorting(
                            sort_by = 'instanceId', 
                            sort_order = 'asc', )
                        ], ), 
                historic_process_instance_query = generic_camunda_client.models.historic_process_instance_query_dto.HistoricProcessInstanceQueryDto(
                    process_instance_id = '0', 
                    process_instance_ids = [
                        '0'
                        ], 
                    process_definition_id = '0', 
                    process_definition_key = '0', 
                    process_definition_key_in = [
                        '0'
                        ], 
                    process_definition_name = '0', 
                    process_definition_name_like = '0', 
                    process_definition_key_not_in = [
                        '0'
                        ], 
                    process_instance_business_key = '0', 
                    process_instance_business_key_like = '0', 
                    root_process_instances = True, 
                    finished = True, 
                    unfinished = True, 
                    with_incidents = True, 
                    with_root_incidents = True, 
                    incident_type = '0', 
                    incident_status = 'open', 
                    incident_message = '0', 
                    incident_message_like = '0', 
                    started_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    started_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    finished_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    finished_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    executed_activity_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    executed_activity_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    executed_job_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    executed_job_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    started_by = '0', 
                    super_process_instance_id = '0', 
                    sub_process_instance_id = '0', 
                    super_case_instance_id = '0', 
                    sub_case_instance_id = '0', 
                    case_instance_id = '0', 
                    tenant_id_in = [
                        '0'
                        ], 
                    without_tenant_id = True, 
                    executed_activity_id_in = [
                        '0'
                        ], 
                    active_activity_id_in = [
                        '0'
                        ], 
                    active = True, 
                    suspended = True, 
                    completed = True, 
                    externally_terminated = True, 
                    internally_terminated = True, 
                    variables = [
                        generic_camunda_client.models.variable_query_parameter_dto.VariableQueryParameterDto(
                            name = '0', 
                            operator = 'eq', 
                            value = generic_camunda_client.models.value.value(), )
                        ], 
                    variable_names_ignore_case = True, 
                    variable_values_ignore_case = True, 
                    or_queries = [
                        generic_camunda_client.models.historic_process_instance_query_dto.HistoricProcessInstanceQueryDto(
                            process_instance_id = '0', 
                            process_definition_id = '0', 
                            process_definition_key = '0', 
                            process_definition_name = '0', 
                            process_definition_name_like = '0', 
                            process_instance_business_key = '0', 
                            process_instance_business_key_like = '0', 
                            root_process_instances = True, 
                            finished = True, 
                            unfinished = True, 
                            with_incidents = True, 
                            with_root_incidents = True, 
                            incident_type = '0', 
                            incident_status = 'open', 
                            incident_message = '0', 
                            incident_message_like = '0', 
                            started_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            started_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            finished_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            finished_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            executed_activity_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            executed_activity_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            executed_job_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            executed_job_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            started_by = '0', 
                            super_process_instance_id = '0', 
                            sub_process_instance_id = '0', 
                            super_case_instance_id = '0', 
                            sub_case_instance_id = '0', 
                            case_instance_id = '0', 
                            without_tenant_id = True, 
                            active = True, 
                            suspended = True, 
                            completed = True, 
                            externally_terminated = True, 
                            internally_terminated = True, 
                            variable_names_ignore_case = True, 
                            variable_values_ignore_case = True, 
                            sorting = [
                                generic_camunda_client.models.historic_process_instance_query_dto_sorting.HistoricProcessInstanceQueryDto_sorting(
                                    sort_by = 'instanceId', 
                                    sort_order = 'asc', )
                                ], )
                        ], 
                    sorting = [
                        generic_camunda_client.models.historic_process_instance_query_dto_sorting.HistoricProcessInstanceQueryDto_sorting(
                            sort_by = 'instanceId', 
                            sort_order = 'asc', )
                        ], )
            )
        else :
            return SetJobRetriesByProcessDto(
        )

    def testSetJobRetriesByProcessDto(self):
        """Test SetJobRetriesByProcessDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from generic_camunda_client.models.abstract_set_removal_time_dto import AbstractSetRemovalTimeDto
from generic_camunda_client.models.activity_instance_dto import ActivityInstanceDto
from generic_camunda_client.models.activity_instance_incident_dto import ActivityInstanceIncidentDto
from generic_camunda_client.models.activity_statistics_result_dto import ActivityStatisticsResultDto
from generic_camunda_client.models.atom_link import AtomLink
from generic_camunda_client.models.attachment_dto import AttachmentDto
from generic_camunda_client.models.attachment_dto_all_of import AttachmentDtoAllOf
from generic_camunda_client.models.authorization_exception_dto import AuthorizationExceptionDto
from generic_camunda_client.models.authorization_exception_dto_all_of import AuthorizationExceptionDtoAllOf
from generic_camunda_client.models.batch_dto import BatchDto
from generic_camunda_client.models.case_definition_dto import CaseDefinitionDto
from generic_camunda_client.models.comment_dto import CommentDto
from generic_camunda_client.models.comment_dto_all_of import CommentDtoAllOf
from generic_camunda_client.models.complete_external_task_dto import CompleteExternalTaskDto
from generic_camunda_client.models.complete_task_dto import CompleteTaskDto
from generic_camunda_client.models.correlation_message_dto import CorrelationMessageDto
from generic_camunda_client.models.count_result_dto import CountResultDto
from generic_camunda_client.models.decision_definition_dto import DecisionDefinitionDto
from generic_camunda_client.models.decision_requirements_definition_dto import DecisionRequirementsDefinitionDto
from generic_camunda_client.models.delete_historic_process_instances_dto import DeleteHistoricProcessInstancesDto
from generic_camunda_client.models.delete_process_instances_dto import DeleteProcessInstancesDto
from generic_camunda_client.models.deployment_dto import DeploymentDto
from generic_camunda_client.models.deployment_dto_all_of import DeploymentDtoAllOf
from generic_camunda_client.models.deployment_resource_dto import DeploymentResourceDto
from generic_camunda_client.models.deployment_with_definitions_dto import DeploymentWithDefinitionsDto
from generic_camunda_client.models.deployment_with_definitions_dto_all_of import DeploymentWithDefinitionsDtoAllOf
from generic_camunda_client.models.duration_report_result_dto import DurationReportResultDto
from generic_camunda_client.models.evaluation_condition_dto import EvaluationConditionDto
from generic_camunda_client.models.event_subscription_dto import EventSubscriptionDto
from generic_camunda_client.models.event_subscription_query_dto import EventSubscriptionQueryDto
from generic_camunda_client.models.event_subscription_query_dto_sorting import EventSubscriptionQueryDtoSorting
from generic_camunda_client.models.exception_dto import ExceptionDto
from generic_camunda_client.models.execution_dto import ExecutionDto
from generic_camunda_client.models.extend_lock_on_external_task_dto import ExtendLockOnExternalTaskDto
from generic_camunda_client.models.external_task_bpmn_error import ExternalTaskBpmnError
from generic_camunda_client.models.external_task_bpmn_error_all_of import ExternalTaskBpmnErrorAllOf
from generic_camunda_client.models.external_task_dto import ExternalTaskDto
from generic_camunda_client.models.external_task_failure_dto import ExternalTaskFailureDto
from generic_camunda_client.models.external_task_query_dto import ExternalTaskQueryDto
from generic_camunda_client.models.external_task_query_dto_sorting import ExternalTaskQueryDtoSorting
from generic_camunda_client.models.fetch_external_task_topic_dto import FetchExternalTaskTopicDto
from generic_camunda_client.models.fetch_external_tasks_dto import FetchExternalTasksDto
from generic_camunda_client.models.form_dto import FormDto
from generic_camunda_client.models.historic_activity_instance_dto import HistoricActivityInstanceDto
from generic_camunda_client.models.historic_activity_instance_query_dto import HistoricActivityInstanceQueryDto
from generic_camunda_client.models.historic_activity_instance_query_dto_sorting import HistoricActivityInstanceQueryDtoSorting
from generic_camunda_client.models.historic_process_instance_dto import HistoricProcessInstanceDto
from generic_camunda_client.models.historic_process_instance_query_dto import HistoricProcessInstanceQueryDto
from generic_camunda_client.models.historic_process_instance_query_dto_sorting import HistoricProcessInstanceQueryDtoSorting
from generic_camunda_client.models.history_time_to_live_dto import HistoryTimeToLiveDto
from generic_camunda_client.models.identity_link_dto import IdentityLinkDto
from generic_camunda_client.models.incident_dto import IncidentDto
from generic_camunda_client.models.incident_statistics_result_dto import IncidentStatisticsResultDto
from generic_camunda_client.models.linkable_dto import LinkableDto
from generic_camunda_client.models.locked_external_task_dto import LockedExternalTaskDto
from generic_camunda_client.models.message_correlation_result_with_variable_dto import MessageCorrelationResultWithVariableDto
from generic_camunda_client.models.metrics_interval_result_dto import MetricsIntervalResultDto
from generic_camunda_client.models.metrics_result_dto import MetricsResultDto
from generic_camunda_client.models.missing_authorization_dto import MissingAuthorizationDto
from generic_camunda_client.models.multi_form_attachment_dto import MultiFormAttachmentDto
from generic_camunda_client.models.multi_form_deployment_dto import MultiFormDeploymentDto
from generic_camunda_client.models.multi_form_variable_binary_dto import MultiFormVariableBinaryDto
from generic_camunda_client.models.parse_exception_dto import ParseExceptionDto
from generic_camunda_client.models.parse_exception_dto_all_of import ParseExceptionDtoAllOf
from generic_camunda_client.models.patch_variables_dto import PatchVariablesDto
from generic_camunda_client.models.priority_dto import PriorityDto
from generic_camunda_client.models.problem_dto import ProblemDto
from generic_camunda_client.models.process_definition_diagram_dto import ProcessDefinitionDiagramDto
from generic_camunda_client.models.process_definition_dto import ProcessDefinitionDto
from generic_camunda_client.models.process_definition_statistics_result_dto import ProcessDefinitionStatisticsResultDto
from generic_camunda_client.models.process_definition_suspension_state_dto import ProcessDefinitionSuspensionStateDto
from generic_camunda_client.models.process_engine_dto import ProcessEngineDto
from generic_camunda_client.models.process_instance_dto import ProcessInstanceDto
from generic_camunda_client.models.process_instance_dto_all_of import ProcessInstanceDtoAllOf
from generic_camunda_client.models.process_instance_modification_dto import ProcessInstanceModificationDto
from generic_camunda_client.models.process_instance_modification_instruction_dto import ProcessInstanceModificationInstructionDto
from generic_camunda_client.models.process_instance_query_dto import ProcessInstanceQueryDto
from generic_camunda_client.models.process_instance_query_dto_sorting import ProcessInstanceQueryDtoSorting
from generic_camunda_client.models.process_instance_suspension_state_async_dto import ProcessInstanceSuspensionStateAsyncDto
from generic_camunda_client.models.process_instance_suspension_state_dto import ProcessInstanceSuspensionStateDto
from generic_camunda_client.models.process_instance_with_variables_dto import ProcessInstanceWithVariablesDto
from generic_camunda_client.models.process_instance_with_variables_dto_all_of import ProcessInstanceWithVariablesDtoAllOf
from generic_camunda_client.models.redeployment_dto import RedeploymentDto
from generic_camunda_client.models.resource_options_dto import ResourceOptionsDto
from generic_camunda_client.models.resource_report_dto import ResourceReportDto
from generic_camunda_client.models.restart_process_instance_dto import RestartProcessInstanceDto
from generic_camunda_client.models.restart_process_instance_modification_instruction_dto import RestartProcessInstanceModificationInstructionDto
from generic_camunda_client.models.retries_dto import RetriesDto
from generic_camunda_client.models.schema_log_entry_dto import SchemaLogEntryDto
from generic_camunda_client.models.schema_log_query_dto import SchemaLogQueryDto
from generic_camunda_client.models.schema_log_query_dto_sorting import SchemaLogQueryDtoSorting
from generic_camunda_client.models.set_job_retries_by_process_dto import SetJobRetriesByProcessDto
from generic_camunda_client.models.set_removal_time_to_historic_process_instances_dto import SetRemovalTimeToHistoricProcessInstancesDto
from generic_camunda_client.models.set_removal_time_to_historic_process_instances_dto_all_of import SetRemovalTimeToHistoricProcessInstancesDtoAllOf
from generic_camunda_client.models.set_retries_for_external_tasks_dto import SetRetriesForExternalTasksDto
from generic_camunda_client.models.set_variables_async_dto import SetVariablesAsyncDto
from generic_camunda_client.models.signal_dto import SignalDto
from generic_camunda_client.models.sort_task_query_parameters_dto import SortTaskQueryParametersDto
from generic_camunda_client.models.start_process_instance_dto import StartProcessInstanceDto
from generic_camunda_client.models.start_process_instance_form_dto import StartProcessInstanceFormDto
from generic_camunda_client.models.suspension_state_dto import SuspensionStateDto
from generic_camunda_client.models.task_bpmn_error_dto import TaskBpmnErrorDto
from generic_camunda_client.models.task_dto import TaskDto
from generic_camunda_client.models.task_escalation_dto import TaskEscalationDto
from generic_camunda_client.models.task_query_dto import TaskQueryDto
from generic_camunda_client.models.task_query_dto_sorting import TaskQueryDtoSorting
from generic_camunda_client.models.telemetry_configuration_dto import TelemetryConfigurationDto
from generic_camunda_client.models.transition_instance_dto import TransitionInstanceDto
from generic_camunda_client.models.trigger_variable_value_dto import TriggerVariableValueDto
from generic_camunda_client.models.trigger_variable_value_dto_all_of import TriggerVariableValueDtoAllOf
from generic_camunda_client.models.user_credentials_dto import UserCredentialsDto
from generic_camunda_client.models.user_dto import UserDto
from generic_camunda_client.models.user_id_dto import UserIdDto
from generic_camunda_client.models.user_profile_dto import UserProfileDto
from generic_camunda_client.models.variable_query_parameter_dto import VariableQueryParameterDto
from generic_camunda_client.models.variable_value_dto import VariableValueDto
from generic_camunda_client.models.version_dto import VersionDto



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class AttachmentDtoAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'task_id': 'str',
        'type': 'str',
        'url': 'str',
        'create_time': 'datetime',
        'removal_time': 'datetime',
        'root_process_instance_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'task_id': 'taskId',
        'type': 'type',
        'url': 'url',
        'create_time': 'createTime',
        'removal_time': 'removalTime',
        'root_process_instance_id': 'rootProcessInstanceId'
    }

    def __init__(self, id=None, name=None, description=None, task_id=None, type=None, url=None, create_time=None, removal_time=None, root_process_instance_id=None, local_vars_configuration=None):  # noqa: E501
        """AttachmentDtoAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._task_id = None
        self._type = None
        self._url = None
        self._create_time = None
        self._removal_time = None
        self._root_process_instance_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if task_id is not None:
            self.task_id = task_id
        if type is not None:
            self.type = type
        if url is not None:
            self.url = url
        if create_time is not None:
            self.create_time = create_time
        self.removal_time = removal_time
        if root_process_instance_id is not None:
            self.root_process_instance_id = root_process_instance_id

    @property
    def id(self):
        """Gets the id of this AttachmentDtoAllOf.  # noqa: E501

        The id of the task attachment.  # noqa: E501

        :return: The id of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AttachmentDtoAllOf.

        The id of the task attachment.  # noqa: E501

        :param id: The id of this AttachmentDtoAllOf.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this AttachmentDtoAllOf.  # noqa: E501

        The name of the task attachment.  # noqa: E501

        :return: The name of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AttachmentDtoAllOf.

        The name of the task attachment.  # noqa: E501

        :param name: The name of this AttachmentDtoAllOf.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this AttachmentDtoAllOf.  # noqa: E501

        The description of the task attachment.  # noqa: E501

        :return: The description of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AttachmentDtoAllOf.

        The description of the task attachment.  # noqa: E501

        :param description: The description of this AttachmentDtoAllOf.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def task_id(self):
        """Gets the task_id of this AttachmentDtoAllOf.  # noqa: E501

        The id of the task to which the attachment belongs.  # noqa: E501

        :return: The task_id of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this AttachmentDtoAllOf.

        The id of the task to which the attachment belongs.  # noqa: E501

        :param task_id: The task_id of this AttachmentDtoAllOf.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def type(self):
        """Gets the type of this AttachmentDtoAllOf.  # noqa: E501

        Indication of the type of content that this attachment refers to. Can be MIME type or any other indication.  # noqa: E501

        :return: The type of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AttachmentDtoAllOf.

        Indication of the type of content that this attachment refers to. Can be MIME type or any other indication.  # noqa: E501

        :param type: The type of this AttachmentDtoAllOf.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def url(self):
        """Gets the url of this AttachmentDtoAllOf.  # noqa: E501

        The url to the remote content of the task attachment.  # noqa: E501

        :return: The url of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AttachmentDtoAllOf.

        The url to the remote content of the task attachment.  # noqa: E501

        :param url: The url of this AttachmentDtoAllOf.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def create_time(self):
        """Gets the create_time of this AttachmentDtoAllOf.  # noqa: E501

        The time the variable was inserted. [Default format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :return: The create_time of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this AttachmentDtoAllOf.

        The time the variable was inserted. [Default format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :param create_time: The create_time of this AttachmentDtoAllOf.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def removal_time(self):
        """Gets the removal_time of this AttachmentDtoAllOf.  # noqa: E501

        The time after which the attachment should be removed by the History Cleanup job. [Default format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :return: The removal_time of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: datetime
        """
        return self._removal_time

    @removal_time.setter
    def removal_time(self, removal_time):
        """Sets the removal_time of this AttachmentDtoAllOf.

        The time after which the attachment should be removed by the History Cleanup job. [Default format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :param removal_time: The removal_time of this AttachmentDtoAllOf.  # noqa: E501
        :type: datetime
        """

        self._removal_time = removal_time

    @property
    def root_process_instance_id(self):
        """Gets the root_process_instance_id of this AttachmentDtoAllOf.  # noqa: E501

        The process instance id of the root process instance that initiated the process containing the task.  # noqa: E501

        :return: The root_process_instance_id of this AttachmentDtoAllOf.  # noqa: E501
        :rtype: str
        """
        return self._root_process_instance_id

    @root_process_instance_id.setter
    def root_process_instance_id(self, root_process_instance_id):
        """Sets the root_process_instance_id of this AttachmentDtoAllOf.

        The process instance id of the root process instance that initiated the process containing the task.  # noqa: E501

        :param root_process_instance_id: The root_process_instance_id of this AttachmentDtoAllOf.  # noqa: E501
        :type: str
        """

        self._root_process_instance_id = root_process_instance_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachmentDtoAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttachmentDtoAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ProcessInstanceWithVariablesDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'variables': 'dict(str, VariableValueDto)',
        'id': 'str',
        'definition_id': 'str',
        'business_key': 'str',
        'case_instance_id': 'str',
        'ended': 'bool',
        'suspended': 'bool',
        'tenant_id': 'str',
        'links': 'list[AtomLink]'
    }

    attribute_map = {
        'variables': 'variables',
        'id': 'id',
        'definition_id': 'definitionId',
        'business_key': 'businessKey',
        'case_instance_id': 'caseInstanceId',
        'ended': 'ended',
        'suspended': 'suspended',
        'tenant_id': 'tenantId',
        'links': 'links'
    }

    def __init__(self, variables=None, id=None, definition_id=None, business_key=None, case_instance_id=None, ended=None, suspended=None, tenant_id=None, links=None, local_vars_configuration=None):  # noqa: E501
        """ProcessInstanceWithVariablesDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._variables = None
        self._id = None
        self._definition_id = None
        self._business_key = None
        self._case_instance_id = None
        self._ended = None
        self._suspended = None
        self._tenant_id = None
        self._links = None
        self.discriminator = None

        if variables is not None:
            self.variables = variables
        if id is not None:
            self.id = id
        if definition_id is not None:
            self.definition_id = definition_id
        if business_key is not None:
            self.business_key = business_key
        if case_instance_id is not None:
            self.case_instance_id = case_instance_id
        if ended is not None:
            self.ended = ended
        if suspended is not None:
            self.suspended = suspended
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if links is not None:
            self.links = links

    @property
    def variables(self):
        """Gets the variables of this ProcessInstanceWithVariablesDto.  # noqa: E501

        The id of the process instance.  # noqa: E501

        :return: The variables of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this ProcessInstanceWithVariablesDto.

        The id of the process instance.  # noqa: E501

        :param variables: The variables of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._variables = variables

    @property
    def id(self):
        """Gets the id of this ProcessInstanceWithVariablesDto.  # noqa: E501

        The id of the process instance.  # noqa: E501

        :return: The id of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProcessInstanceWithVariablesDto.

        The id of the process instance.  # noqa: E501

        :param id: The id of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def definition_id(self):
        """Gets the definition_id of this ProcessInstanceWithVariablesDto.  # noqa: E501

        The id of the process definition that this process instance belongs to.  # noqa: E501

        :return: The definition_id of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: str
        """
        return self._definition_id

    @definition_id.setter
    def definition_id(self, definition_id):
        """Sets the definition_id of this ProcessInstanceWithVariablesDto.

        The id of the process definition that this process instance belongs to.  # noqa: E501

        :param definition_id: The definition_id of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: str
        """

        self._definition_id = definition_id

    @property
    def business_key(self):
        """Gets the business_key of this ProcessInstanceWithVariablesDto.  # noqa: E501

        The business key of the process instance.  # noqa: E501

        :return: The business_key of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: str
        """
        return self._business_key

    @business_key.setter
    def business_key(self, business_key):
        """Sets the business_key of this ProcessInstanceWithVariablesDto.

        The business key of the process instance.  # noqa: E501

        :param business_key: The business_key of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: str
        """

        self._business_key = business_key

    @property
    def case_instance_id(self):
        """Gets the case_instance_id of this ProcessInstanceWithVariablesDto.  # noqa: E501

        The id of the case instance associated with the process instance.  # noqa: E501

        :return: The case_instance_id of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: str
        """
        return self._case_instance_id

    @case_instance_id.setter
    def case_instance_id(self, case_instance_id):
        """Sets the case_instance_id of this ProcessInstanceWithVariablesDto.

        The id of the case instance associated with the process instance.  # noqa: E501

        :param case_instance_id: The case_instance_id of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: str
        """

        self._case_instance_id = case_instance_id

    @property
    def ended(self):
        """Gets the ended of this ProcessInstanceWithVariablesDto.  # noqa: E501

        A flag indicating whether the process instance has ended or not. Deprecated: will always be false!  # noqa: E501

        :return: The ended of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: bool
        """
        return self._ended

    @ended.setter
    def ended(self, ended):
        """Sets the ended of this ProcessInstanceWithVariablesDto.

        A flag indicating whether the process instance has ended or not. Deprecated: will always be false!  # noqa: E501

        :param ended: The ended of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: bool
        """

        self._ended = ended

    @property
    def suspended(self):
        """Gets the suspended of this ProcessInstanceWithVariablesDto.  # noqa: E501

        A flag indicating whether the process instance is suspended or not.  # noqa: E501

        :return: The suspended of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: bool
        """
        return self._suspended

    @suspended.setter
    def suspended(self, suspended):
        """Sets the suspended of this ProcessInstanceWithVariablesDto.

        A flag indicating whether the process instance is suspended or not.  # noqa: E501

        :param suspended: The suspended of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: bool
        """

        self._suspended = suspended

    @property
    def tenant_id(self):
        """Gets the tenant_id of this ProcessInstanceWithVariablesDto.  # noqa: E501

        The tenant id of the process instance.  # noqa: E501

        :return: The tenant_id of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this ProcessInstanceWithVariablesDto.

        The tenant id of the process instance.  # noqa: E501

        :param tenant_id: The tenant_id of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def links(self):
        """Gets the links of this ProcessInstanceWithVariablesDto.  # noqa: E501

        The links associated to this resource, with `method`, `href` and `rel`.  # noqa: E501

        :return: The links of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :rtype: list[AtomLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this ProcessInstanceWithVariablesDto.

        The links associated to this resource, with `method`, `href` and `rel`.  # noqa: E501

        :param links: The links of this ProcessInstanceWithVariablesDto.  # noqa: E501
        :type: list[AtomLink]
        """

        self._links = links

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessInstanceWithVariablesDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProcessInstanceWithVariablesDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ProcessInstanceModificationDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'skip_custom_listeners': 'bool',
        'skip_io_mappings': 'bool',
        'instructions': 'list[ProcessInstanceModificationInstructionDto]',
        'annotation': 'str'
    }

    attribute_map = {
        'skip_custom_listeners': 'skipCustomListeners',
        'skip_io_mappings': 'skipIoMappings',
        'instructions': 'instructions',
        'annotation': 'annotation'
    }

    def __init__(self, skip_custom_listeners=None, skip_io_mappings=None, instructions=None, annotation=None, local_vars_configuration=None):  # noqa: E501
        """ProcessInstanceModificationDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._skip_custom_listeners = None
        self._skip_io_mappings = None
        self._instructions = None
        self._annotation = None
        self.discriminator = None

        self.skip_custom_listeners = skip_custom_listeners
        self.skip_io_mappings = skip_io_mappings
        if instructions is not None:
            self.instructions = instructions
        if annotation is not None:
            self.annotation = annotation

    @property
    def skip_custom_listeners(self):
        """Gets the skip_custom_listeners of this ProcessInstanceModificationDto.  # noqa: E501

        Skip execution listener invocation for activities that are started or ended as part of this request.  # noqa: E501

        :return: The skip_custom_listeners of this ProcessInstanceModificationDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_custom_listeners

    @skip_custom_listeners.setter
    def skip_custom_listeners(self, skip_custom_listeners):
        """Sets the skip_custom_listeners of this ProcessInstanceModificationDto.

        Skip execution listener invocation for activities that are started or ended as part of this request.  # noqa: E501

        :param skip_custom_listeners: The skip_custom_listeners of this ProcessInstanceModificationDto.  # noqa: E501
        :type: bool
        """

        self._skip_custom_listeners = skip_custom_listeners

    @property
    def skip_io_mappings(self):
        """Gets the skip_io_mappings of this ProcessInstanceModificationDto.  # noqa: E501

        Skip execution of [input/output variable mappings](https://docs.camunda.org/manual/7.14/user-guide/process-engine/variables/#input-output-variable-mapping) for activities that are started or ended as part of this request.  # noqa: E501

        :return: The skip_io_mappings of this ProcessInstanceModificationDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_io_mappings

    @skip_io_mappings.setter
    def skip_io_mappings(self, skip_io_mappings):
        """Sets the skip_io_mappings of this ProcessInstanceModificationDto.

        Skip execution of [input/output variable mappings](https://docs.camunda.org/manual/7.14/user-guide/process-engine/variables/#input-output-variable-mapping) for activities that are started or ended as part of this request.  # noqa: E501

        :param skip_io_mappings: The skip_io_mappings of this ProcessInstanceModificationDto.  # noqa: E501
        :type: bool
        """

        self._skip_io_mappings = skip_io_mappings

    @property
    def instructions(self):
        """Gets the instructions of this ProcessInstanceModificationDto.  # noqa: E501

        JSON array of modification instructions. The instructions are executed in the order they are in.  # noqa: E501

        :return: The instructions of this ProcessInstanceModificationDto.  # noqa: E501
        :rtype: list[ProcessInstanceModificationInstructionDto]
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """Sets the instructions of this ProcessInstanceModificationDto.

        JSON array of modification instructions. The instructions are executed in the order they are in.  # noqa: E501

        :param instructions: The instructions of this ProcessInstanceModificationDto.  # noqa: E501
        :type: list[ProcessInstanceModificationInstructionDto]
        """

        self._instructions = instructions

    @property
    def annotation(self):
        """Gets the annotation of this ProcessInstanceModificationDto.  # noqa: E501

        An arbitrary text annotation set by a user for auditing reasons.  # noqa: E501

        :return: The annotation of this ProcessInstanceModificationDto.  # noqa: E501
        :rtype: str
        """
        return self._annotation

    @annotation.setter
    def annotation(self, annotation):
        """Sets the annotation of this ProcessInstanceModificationDto.

        An arbitrary text annotation set by a user for auditing reasons.  # noqa: E501

        :param annotation: The annotation of this ProcessInstanceModificationDto.  # noqa: E501
        :type: str
        """

        self._annotation = annotation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessInstanceModificationDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProcessInstanceModificationDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.external_task_dto import ExternalTaskDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestExternalTaskDto(unittest.TestCase):
    """ExternalTaskDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ExternalTaskDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.external_task_dto.ExternalTaskDto()  # noqa: E501
        if include_optional :
            return ExternalTaskDto(
                activity_id = '0', 
                activity_instance_id = '0', 
                error_message = '0', 
                execution_id = '0', 
                id = '0', 
                lock_expiration_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                process_definition_id = '0', 
                process_definition_key = '0', 
                process_definition_version_tag = '0', 
                process_instance_id = '0', 
                tenant_id = '0', 
                retries = 56, 
                suspended = True, 
                worker_id = '0', 
                topic_name = '0', 
                priority = 56, 
                business_key = '0'
            )
        else :
            return ExternalTaskDto(
        )

    def testExternalTaskDto(self):
        """Test ExternalTaskDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.incident_api import IncidentApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestIncidentApi(unittest.TestCase):
    """IncidentApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.incident_api.IncidentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_incident(self):
        """Test case for get_incident

        Get Incident  # noqa: E501
        """
        pass

    def test_get_incidents(self):
        """Test case for get_incidents

        Get List  # noqa: E501
        """
        pass

    def test_get_incidents_count(self):
        """Test case for get_incidents_count

        Get List Count  # noqa: E501
        """
        pass

    def test_resolve_incident(self):
        """Test case for resolve_incident

        Resolve Incident  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.process_definition_api import ProcessDefinitionApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestProcessDefinitionApi(unittest.TestCase):
    """ProcessDefinitionApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.process_definition_api.ProcessDefinitionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_process_definition(self):
        """Test case for delete_process_definition

        Delete  # noqa: E501
        """
        pass

    def test_delete_process_definitions_by_key(self):
        """Test case for delete_process_definitions_by_key

        Delete By Key  # noqa: E501
        """
        pass

    def test_delete_process_definitions_by_key_and_tenant_id(self):
        """Test case for delete_process_definitions_by_key_and_tenant_id

        Delete By Key  # noqa: E501
        """
        pass

    def test_get_activity_statistics(self):
        """Test case for get_activity_statistics

        Get Activity Instance Statistics  # noqa: E501
        """
        pass

    def test_get_activity_statistics_by_process_definition_key(self):
        """Test case for get_activity_statistics_by_process_definition_key

        Get Activity Instance Statistics  # noqa: E501
        """
        pass

    def test_get_activity_statistics_by_process_definition_key_and_tenant_id(self):
        """Test case for get_activity_statistics_by_process_definition_key_and_tenant_id

        Get Activity Instance Statistics  # noqa: E501
        """
        pass

    def test_get_deployed_start_form(self):
        """Test case for get_deployed_start_form

        Get Deployed Start Form  # noqa: E501
        """
        pass

    def test_get_deployed_start_form_by_key(self):
        """Test case for get_deployed_start_form_by_key

        Get Deployed Start Form  # noqa: E501
        """
        pass

    def test_get_deployed_start_form_by_key_and_tenant_id(self):
        """Test case for get_deployed_start_form_by_key_and_tenant_id

        Get Deployed Start Form  # noqa: E501
        """
        pass

    def test_get_latest_process_definition_by_tenant_id(self):
        """Test case for get_latest_process_definition_by_tenant_id

        Get  # noqa: E501
        """
        pass

    def test_get_process_definition(self):
        """Test case for get_process_definition

        Get  # noqa: E501
        """
        pass

    def test_get_process_definition_bpmn20_xml(self):
        """Test case for get_process_definition_bpmn20_xml

        Get XML  # noqa: E501
        """
        pass

    def test_get_process_definition_bpmn20_xml_by_key(self):
        """Test case for get_process_definition_bpmn20_xml_by_key

        Get XML  # noqa: E501
        """
        pass

    def test_get_process_definition_bpmn20_xml_by_key_and_tenant_id(self):
        """Test case for get_process_definition_bpmn20_xml_by_key_and_tenant_id

        Get XML  # noqa: E501
        """
        pass

    def test_get_process_definition_by_key(self):
        """Test case for get_process_definition_by_key

        Get  # noqa: E501
        """
        pass

    def test_get_process_definition_diagram(self):
        """Test case for get_process_definition_diagram

        Get Diagram  # noqa: E501
        """
        pass

    def test_get_process_definition_diagram_by_key(self):
        """Test case for get_process_definition_diagram_by_key

        Get Diagram  # noqa: E501
        """
        pass

    def test_get_process_definition_diagram_by_key_and_tenant_id(self):
        """Test case for get_process_definition_diagram_by_key_and_tenant_id

        Get Diagram  # noqa: E501
        """
        pass

    def test_get_process_definition_statistics(self):
        """Test case for get_process_definition_statistics

        Get Process Instance Statistics  # noqa: E501
        """
        pass

    def test_get_process_definitions(self):
        """Test case for get_process_definitions

        Get List  # noqa: E501
        """
        pass

    def test_get_process_definitions_count(self):
        """Test case for get_process_definitions_count

        Get List Count  # noqa: E501
        """
        pass

    def test_get_rendered_start_form(self):
        """Test case for get_rendered_start_form

        Get Rendered Start Form  # noqa: E501
        """
        pass

    def test_get_rendered_start_form_by_key(self):
        """Test case for get_rendered_start_form_by_key

        Get Rendered Start Form  # noqa: E501
        """
        pass

    def test_get_rendered_start_form_by_key_and_tenant_id(self):
        """Test case for get_rendered_start_form_by_key_and_tenant_id

        Get Rendered Start Form  # noqa: E501
        """
        pass

    def test_get_start_form(self):
        """Test case for get_start_form

        Get Start Form Key  # noqa: E501
        """
        pass

    def test_get_start_form_by_key(self):
        """Test case for get_start_form_by_key

        Get Start Form Key  # noqa: E501
        """
        pass

    def test_get_start_form_by_key_and_tenant_id(self):
        """Test case for get_start_form_by_key_and_tenant_id

        Get Start Form Key  # noqa: E501
        """
        pass

    def test_get_start_form_variables(self):
        """Test case for get_start_form_variables

        Get Start Form Variables  # noqa: E501
        """
        pass

    def test_get_start_form_variables_by_key(self):
        """Test case for get_start_form_variables_by_key

        Get Start Form Variables  # noqa: E501
        """
        pass

    def test_get_start_form_variables_by_key_and_tenant_id(self):
        """Test case for get_start_form_variables_by_key_and_tenant_id

        Get Start Form Variables  # noqa: E501
        """
        pass

    def test_restart_process_instance(self):
        """Test case for restart_process_instance

        Restart Process Instance  # noqa: E501
        """
        pass

    def test_restart_process_instance_async_operation(self):
        """Test case for restart_process_instance_async_operation

        Restart Process Instance Async  # noqa: E501
        """
        pass

    def test_start_process_instance(self):
        """Test case for start_process_instance

        Start Instance  # noqa: E501
        """
        pass

    def test_start_process_instance_by_key(self):
        """Test case for start_process_instance_by_key

        Start Instance  # noqa: E501
        """
        pass

    def test_start_process_instance_by_key_and_tenant_id(self):
        """Test case for start_process_instance_by_key_and_tenant_id

        Start Instance  # noqa: E501
        """
        pass

    def test_submit_form(self):
        """Test case for submit_form

        Submit Start Form  # noqa: E501
        """
        pass

    def test_submit_form_by_key(self):
        """Test case for submit_form_by_key

        Submit Start Form  # noqa: E501
        """
        pass

    def test_submit_form_by_key_and_tenant_id(self):
        """Test case for submit_form_by_key_and_tenant_id

        Submit Start Form  # noqa: E501
        """
        pass

    def test_update_history_time_to_live_by_process_definition_id(self):
        """Test case for update_history_time_to_live_by_process_definition_id

        Update History Time to Live  # noqa: E501
        """
        pass

    def test_update_history_time_to_live_by_process_definition_key(self):
        """Test case for update_history_time_to_live_by_process_definition_key

        Update History Time to Live  # noqa: E501
        """
        pass

    def test_update_history_time_to_live_by_process_definition_key_and_tenant_id(self):
        """Test case for update_history_time_to_live_by_process_definition_key_and_tenant_id

        Update History Time to Live  # noqa: E501
        """
        pass

    def test_update_process_definition_suspension_state(self):
        """Test case for update_process_definition_suspension_state

        Activate/Suspend By Key  # noqa: E501
        """
        pass

    def test_update_process_definition_suspension_state_by_id(self):
        """Test case for update_process_definition_suspension_state_by_id

        Activate/Suspend By Id  # noqa: E501
        """
        pass

    def test_update_process_definition_suspension_state_by_key(self):
        """Test case for update_process_definition_suspension_state_by_key

        Activate/Suspend by Id  # noqa: E501
        """
        pass

    def test_update_process_definition_suspension_state_by_key_and_tenant_id(self):
        """Test case for update_process_definition_suspension_state_by_key_and_tenant_id

        Activate/Suspend by Id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
